Derive relative difference from terminal year from a retrospective analysis.
Usage
get_retrospective_relative_difference(retro_data)
Arguments
- retro_data
Dataframe outputted from do_retrospective function
Value
Returns a data frame with relative difference of SSB and recruitment from the terminal year
See also
Other Model Diagnostics:
do_jitter(),
do_likelihood_profile(),
do_retrospective(),
do_runs_test(),
get_catch_fits_plot(),
get_comp_prop(),
get_idx_fits(),
get_idx_fits_plot(),
get_model_rep_from_mcmc(),
get_nLL_plot(),
get_osa(),
get_retrospective_plot(),
plot_resids()