Skip to contents

A dataset containing the necessary elements for the BSAI Atka mackerel case study, including model inputs (dimensions, biologicals, catch, survey index, and compositions), the ADMB MLE parameter estimates, and the AMAK derived quantities and likelihood components used for bridge verification.

Usage

sgl_rg_bsai_atka_data

Format

A list with model inputs at the top level, mle (AMAK maximum likelihood estimates), and amak (AMAK derived quantities and likelihood components for bridge comparison)

2024 Federal BSAI Atka Mackerel Assessment, Model 16.0b