Skip to contents

A dataset containing the necessary elements for the BSAI northern rockfish case study, including model inputs (dimensions, biologicals, catch, indices, and compositions), the ADMB MLE parameter estimates, and the ADMB derived quantities and likelihood components used for bridge verification.

Usage

sgl_rg_bsai_nork_data

Format

A list with model inputs at the top level, mle (ADMB maximum likelihood estimates), and admb (ADMB derived quantities and likelihood components for bridge comparison)

2023 Federal BSAI Northern Rockfish Assessment