Skip to contents

A dataset containing the necessary elements for the BSAI blackspotted and rougheye rockfish case study, including model inputs (dimensions, biologicals, catch, indices, and compositions) and the ADMB MLE parameter estimates and derived quantities used for bridge verification.

Usage

sgl_rg_rebs_data

Format

A list with components inputs (model dimensions and data), mle (ADMB maximum likelihood estimates), and admb (ADMB derived quantities and likelihood components for bridge comparison)