Setup fishing mortality and catch observations
Setup_Mod_Catch_and_F.RdSetup fishing mortality and catch observations
Usage
Setup_Mod_Catch_and_F(
input_list,
ObsCatch,
catch_units = array("biom", dim = c(input_list$data$n_regions,
input_list$data$n_fish_fleets)),
Catch_Type = array(1, dim = c(length(input_list$data$years),
input_list$data$n_fish_fleets)),
UseCatch,
Use_F_pen = 1,
est_all_regional_F = 1,
sigmaC_spec = "fix",
sigmaC_agg_spec = "fix",
sigmaF_spec = "fix",
sigmaF_agg_spec = "fix",
...
)Arguments
- input_list
A list containing data, parameters, and map lists used by the model.
- ObsCatch
Numeric array of observed catches, dimensioned
[n_regions, n_years, n_fish_fleets].- catch_units
Catch units - Array dimensioned by n_regions x n_fish_fleets
"abd": Catch units in abundance"biom": Catch units in biomass (default)
- Catch_Type
Integer matrix with dimensions
[n_years, n_fish_fleets], specifying catch data types:0: Use aggregated catch data for the year.1: Use region-specific catch data for the year.
- UseCatch
Indicator array
[n_regions, n_years, n_fish_fleets]specifying whether to include catch data in the fit:0: Do not use catch data.1: Use catch data and fit.
- Use_F_pen
Integer flag indicating whether to apply a fishing mortality penalty:
0: Do not apply penalty.1: Apply penalty.
- est_all_regional_F
Integer flag indicating whether all regional fishing mortality deviations are estimated:
0: Some fishing mortality deviations are aggregated across regions.1: All fishing mortality deviations are regional.
- sigmaC_spec
Character string specifying observation error structure for catch data. Default behavior fixes
sigmaCat a starting value of1e-3(log-scaleln_sigmaC = log(1e-3)) for all regions, years, and fleets. Other options include:"est_shared_f": EstimatesigmaCshared across fishery fleets, unique by region and year."est_shared_r": EstimatesigmaCshared across regions, unique by fleet and year."est_shared_y": EstimatesigmaCshared across years, unique by region and fleet."est_shared_r_f": EstimatesigmaCshared across regions and fleets, unique by year."est_shared_f_y": EstimatesigmaCshared across fleets and years, unique by region."est_shared_r_y": EstimatesigmaCshared across regions and years, unique by fleet."est_shared_r_y_f": Estimate singlesigmaCshared across regions, years, and fleets."fix": FixsigmaCat the starting value."est_all": Estimate separatesigmaCfor each region, year, and fleet combination.
- sigmaC_agg_spec
Character string specifying process error structure for aggregated catch observation error. Default fixes
sigmaC_aggat the starting value (log-scalesigmaC_agg). Other options include:"est_shared_f": EstimatesigmaC_aggshared across fishery fleets, unique by year."est_shared_y": EstimatesigmaC_aggshared across years, unique by fleet."est_shared_y_f": Estimate singlesigmaC_aggshared across years and fleets."fix": Fix at the starting value."est_all": Estimate separate parameters for each year and fleet combination.
- sigmaF_spec
Character string specifying process error structure for fishing mortality. Default fixes
sigmaFat1on the log scale (i.e.,ln_sigmaF = 0). Other options include:"est_shared_f": EstimatesigmaFshared across fishery fleets."est_shared_r": EstimatesigmaFshared across regions but unique by fleet."est_shared_r_f": EstimatesigmaFshared across regions and fleets."fix": FixsigmaFat the starting value."est_all": Estimate separatesigmaFfor each region and fleet.
- sigmaF_agg_spec
Character string specifying process error structure for aggregated fishing mortality. Default fixes
sigmaF_aggat the starting value (log-scaleln_sigmaF_agg). Other options include:"est_shared_f": EstimatesigmaF_aggshared across fishery fleets."fix": Fix at the starting value."est_all": Estimate separate parameters for each fishery fleet.
- ...
Additional arguments specifying starting values for
ln_sigmaC,ln_sigmaF, andln_sigmaF_agg.