Combine a parameter function and a data list for RTMB
cmb.RdReturns a closure that calls f(p, d), allowing the data list to be
fixed at construction time so that RTMB::MakeADFun receives a
single-argument objective function of the form function(p).
Arguments
- f
Function with signature
function(pars, data), typicallySPoRC_rtmb.- d
Named list of model data passed as the second argument to
fon every call.