Mean size of the plus group
plus_group_size.RdAdjust for fish older than the accumulator age: the plus group is a mixture of ages from the accumulator age onward, their numbers decaying at \(Z = 0.2\) per year, and their size growing linearly from the curve's value at the accumulator age to \(L_\infty\) over a second lifetime, $$\bar L_+ = \frac{\sum_{a=0}^{n} e^{-0.2 a}\,[L_n + (a/n)(L_\infty - L_n)]}{\sum_{a=0}^{n} e^{-0.2 a}}$$ with \(n\) the accumulator age.