BSAI Atka Mackerel data for single region case study
sgl_rg_bsai_atka_data.RdA dataset containing the necessary elements for the BSAI Atka mackerel case study, including model inputs (dimensions, biologicals, catch, survey index, and compositions), the ADMB MLE parameter estimates, and the AMAK derived quantities and likelihood components used for bridge verification.