BSAI Pacific Ocean Perch data for single region case study
sgl_rg_bsai_pop_data.RdA dataset containing the necessary elements for the BSAI Pacific ocean perch case study, including model inputs (dimensions, biologicals, catch, two survey indices, and compositions), the ADMB MLE parameter estimates, and the ADMB derived quantities and likelihood components used for bridge verification.