GOA Northern Rockfish data for single region case study
sgl_rg_goa_nork_data.RdA dataset containing the necessary elements for the GOA northern rockfish case study, including model inputs (dimensions, biologicals, catch, indices, and compositions), the ADMB MLE parameter estimates, and the ADMB derived quantities and likelihood components used for bridge verification.